@@ -1,13 +1,11 @@
-"print.predcoca" <-
-function(x, digits = max(3, getOption("digits") - 3),...)
-  {
+`print.predcoca` <- function(x, digits = max(3, getOption("digits") - 3),
+                             ...) {
     cat("\nPredictive Co-Correspondence Analysis\n\n")
     writeLines(strwrap(pasteCall(x$call)))
-    if (!is.null(x$lambda))
-      {
+    if (!is.null(x$lambda)) {
         cat("\nEigenvalues:\n")
         print(round(x$lambda, digits), ..., print.gap = 2)
-      } else {
+    } else {
         pcentX <- (x$varianceExp$Xblock / x$totalVar$Xblock) * 100
         Xvar.mat <- rbind(pcentX, cumsum(pcentX))
         pcentY <- (x$varianceExp$Yblock / x$totalVar$Yblock) * 100
@@ -20,8 +18,7 @@ function(x, digits = max(3, getOption("digits") - 3),...)
         cat("\nX-block: variance explained in", x$nam.dat$namX,
             "(predictor) \n", sep = " ")
         print(round(Xvar.mat, digits), ..., print.gap = 2)
-      }
+    }
     cat("\n")
     invisible(x)
-  }
-
+}
